@@ -23,20 +23,18 @@
 #include <KCModule>
 
 #include <QVariant>
-namespace PimCommon
-{
+namespace PimCommon {
 class ConfigurePluginsWidget;
 }
-namespace KAddressBook
-{
+namespace KAddressBook {
 class KCMKaddressbookPluginsConfig : public KCModule
 {
     Q_OBJECT
 public:
     KCMKaddressbookPluginsConfig(QWidget *parent, const QVariantList &args);
-    void load() Q_DECL_OVERRIDE;
-    void save() Q_DECL_OVERRIDE;
-    void defaults() Q_DECL_OVERRIDE;
+    void load() override;
+    void save() override;
+    void defaults() override;
 private Q_SLOTS:
     void slotConfigChanged();
 private:
